@@ -387,7 +387,7 @@ class LipidInteraction:
             return [self._duration[residue_id] for residue_id in selected_residue_id]
 
     def compute_residue_occupancy(self, residue_id=None):
-        """Calculate the percentage of frames in which lipid contacts are formed for residues.
+        """Calculate the percentage of frames in which the specified lipid contacts are formed for residues.
 
         Parameters
         ----------
@@ -423,7 +423,7 @@ class LipidInteraction:
         """Calculate the average number of contacting lipids for residues.
 
         Only lipids of the specified name will be calculated. The number of contacting lipids are calculated from
-        the frames in which lipid contacts are formed with the residues.
+        the frames in which the specified lipid contacts are formed with the residues.
 
         Parameters
         ----------
@@ -636,7 +636,7 @@ class LipidInteraction:
             return [self._duration_BS[bs_id] for bs_id in selected_bs_id]
 
     def compute_site_occupancy(self, binding_site_id=None):
-        """Calculate the percentage of frames in which lipid contacts are formed for binding sites.
+        """Calculate the percentage of frames in which the specified lipid contacts are formed for binding sites.
 
         Parameters
         ----------
@@ -679,7 +679,7 @@ class LipidInteraction:
         """Calculate the average number of contacting lipids for binding site.
 
         Only lipids of the specified name will be calculated. The number of contacting lipids are calculated from
-        the frames in which lipid contacts are formed with the binding sites.
+        the frames in which the specified lipid contacts are formed with binding sites.
 
         Parameters
         ----------
